'''Inventory
'''

from pyglet.gl import *

class Inventory(object):
    def __init__(self):
        self.inv = []
        self.score = 0
        self.max_items = 5
        self.height = 250
        self.x = 0
        self.y = 150
        self.iconsize = self.height / self.max_items
        self.labels = []
        for i in range(self.max_items):
            self.labels.append(pyglet.text.Label( \
                text = str(i + 1), font_size = 18, x = self.iconsize + 10,
                y = self.y + 10 + self.iconsize * (self.max_items - 1 - i),
                anchor_x = 'left', anchor_y = 'bottom'))

    def slots_left(self):
        return(self.max_items - len(self.inv))

    def add_item(self, action, img):
        if len(self.inv) < self.max_items:
            sprite = pyglet.sprite.Sprite(img)
            sprite.scale = self.iconsize / float(img.width)
            sprite.x = self.iconsize / 2
            sprite.y = self.iconsize / 2
            self.inv.append(InvItem(action, sprite))

    def use_item(self,itemnum):
        if itemnum > len(self.inv):
            return
        i = itemnum - 1
        item = self.inv[i]
        del self.inv[i]
        item.action()

    def clear(self):
        self.inv = []
        
    def draw(self,offset):
        for i in range(self.max_items):
            x1 = self.x
            y1 = self.y + (self.max_items - 1 - i) * self.iconsize
            x2 = self.x + self.iconsize
            y2 = y1 + self.iconsize
            glColor3f(0.3,0.3,0.3)
            glBegin(GL_QUADS)
            glVertex2f(x1, y1)
            glVertex2f(x2, y1)
            glVertex2f(x2, y2)
            glVertex2f(x1, y2)
            glEnd()
            glColor3f(0.0,0.0,0.0)
            glBegin(GL_LINE_LOOP)
            glVertex2f(x1, y1)
            glVertex2f(x2, y1)
            glVertex2f(x2, y2)
            glVertex2f(x1, y2)
            glEnd()
            self.labels[i].draw()
            glPushMatrix()
            glLoadIdentity()
            glTranslatef(0.0, offset - self.iconsize, 0.0)
            for item in self.inv:
                item.draw()
                glTranslatef(0.0, -self.iconsize, 0.0)
            glPopMatrix()
            

class InvItem(object):
    def __init__(self, action, sprite):
        self.action = action
        self.sprite = sprite

    def draw(self):
        self.sprite.draw()

    def action(self):
        self.action()


